@@ -21,7 +21,12 @@ from .object_utils import (
     duplicate,
     load_obj,
 )
-from .material_utils import set_inst_material, load_hdri_world, build_tex
+from .material_utils import (
+    set_inst_material,
+    set_vertex_color_material,
+    load_hdri_world,
+    build_tex,
+)
 from .render_utils import (
     set_cycles_compute_device_type,
     set_image_render,
@@ -48,3 +53,6 @@ from .pose_utils import (
 )
 from .physic_utils import set_origin_and_record_old_v0
 from .domain_randomzition import texture_bsdf_dr, load_distractor
+
+# tools
+from boxx import tree, show
